#!/bin/bash
# Docker entrypoint of the docker image of the CES Slurm Simulator
#
# This script was adapted from https://github.com/jafreck/docker-ubuntu-slurm/blob/master/docker-entrypoint.sh
# and also from https://github.com/giovtorres/docker-centos7-slurm/
#
# Copyright (C) 2023  Manuel G. Marciani
# BSC-CNS - Earth Sciences

function check_running_status {
    for count in {10..0}; do
        STATUS=$(/usr/bin/supervisorctl status $1 | awk '{print $2}')
        echo "docker-entrypoint.sh: $1 is in the $STATUS state."
        if [[ "$STATUS" = "RUNNING" ]]
        then
            break
        else
            sleep 1
        fi
    done
}

if [ ! -d "/var/lib/mysql/slurm_acct_db" ]; then
    /usr/bin/mysqld_safe --datadir='/var/lib/mysql' &

    sleep 10

    echo "docker-entrypoint.sh: Creating Slurm acct database"
    mysql -NBe "CREATE DATABASE slurm_sacct_db"
    mysql -NBe "GRANT USAGE ON *.* to 'root'@'localhost'"
    mysql -NBe "GRANT ALL PRIVILEGES on slurm_sacct_db.* to 'root'@'localhost'"
    mysql -NBe "FLUSH PRIVILEGES"
    echo "docker-entrypoint.sh: Slurm acct database created."

    killall mysqld
fi

echo "docker-entrypoint.sh: Starting supervisord process manager"
/usr/bin/supervisord --configuration /etc/supervisord.conf

# check if supervisord has launched mysqld
check_running_status mysqld

# wait for mysqld to spool up
sleep 30

python3 run_simulation.py workloads/workload.swf $@  

